// This is a scripted coppercube action.
// It scales an object animated to a specific target scale.
//
// The following embedded xml is for the editor and describes how the action can be edited:
// Supported types are: int, float, string, bool, color, vect3d, scenenode, texture, action
/*
	<action jsname="action_AnimateScale" description="Animate Scale of 3D Object">
		<property name="TimeMs" type="int" default="500" />
		<property name="TargetScale" type="vect3d" default="2.0, 2.0, 2.0" />
	</action>
*/

action_AnimateScale = function()
{
};

// called when the action is executed 
action_AnimateScale.prototype.execute = function(currentNode)
{
	var me = this; 
	this.registeredFunction = function() { me.scaleAnimFunc(); }; 
	
	ccbRegisterOnFrameEvent(this.registeredFunction);	
	
	this.startTime = (new Date()).getTime();
	this.endTime = this.startTime + this.TimeMs;
	this.currentNode = currentNode;
	this.startScale = ccbGetSceneNodeProperty(currentNode, "Scale");
}


action_AnimateScale.prototype.scaleAnimFunc = function()
{
	var now = (new Date()).getTime();
	
	if (now > this.endTime)
	{
		ccbInvokeAction(this.ActionToDo, this.registeredFunction);
		ccbUnregisterOnFrameEvent(this.registeredFunction);
		ccbSetSceneNodeProperty(this.currentNode, "Scale", this.TargetScale);		
	}
	else
	{
		var delta = (now - this.startTime) / this.TimeMs;
		if (delta > 1.0) delta = 1.0;
		
		var x = this.startScale.x + ((this.TargetScale.x - this.startScale.x)*delta);
		var y = this.startScale.y + ((this.TargetScale.y - this.startScale.y)*delta);
		var z = this.startScale.z + ((this.TargetScale.z - this.startScale.z)*delta);
		
		ccbSetSceneNodeProperty(this.currentNode, "Scale", x, y, z);				
	}
}
